[evolution-mapi] Bug 615716 — Miscellaneous string fixes



commit 661a2786694f7f1ab4cc6f6c67851818ad7779f9
Author: Philip Withnall <philip tecnocode co uk>
Date:   Tue Apr 13 17:57:34 2010 +0100

    Bug 615716 â?? Miscellaneous string fixes
    
    Mostly small punctuation fixes, including conversion of ASCII ellipses to
    proper Unicode ellipses. Closes: bgo#615716

 .../exchange-mapi-account-settings.c               |    4 ++--
 .../exchange-mapi-account-setup.c                  |    4 ++--
 src/addressbook/e-book-backend-mapi-gal.c          |    8 ++++----
 src/camel/camel-mapi-provider.c                    |    4 ++--
 src/camel/camel-mapi-store.c                       |   12 ++++++------
 5 files changed, 16 insertions(+), 16 deletions(-)
---
diff --git a/src/account-setup-eplugin/exchange-mapi-account-settings.c b/src/account-setup-eplugin/exchange-mapi-account-settings.c
index b4b199e..d09536f 100644
--- a/src/account-setup-eplugin/exchange-mapi-account-settings.c
+++ b/src/account-setup-eplugin/exchange-mapi-account-settings.c
@@ -157,7 +157,7 @@ mapi_settings_run_folder_size_dialog (const gchar *profile, gpointer data)
 
 	dialog_data->spinner = gtk_spinner_new ();
 	gtk_spinner_start (GTK_SPINNER (dialog_data->spinner));
-	dialog_data->spinner_label = gtk_label_new (_("Fetching folder list ..."));
+	dialog_data->spinner_label = gtk_label_new (_("Fetching folder listâ?¦"));
 
 	dialog_data->spinner_hbox = (GtkBox *) gtk_hbox_new (TRUE, 6);
 
@@ -341,7 +341,7 @@ org_gnome_exchange_mapi_settings (EPlugin *epl, EConfigHookItemFactoryData *data
 	lbl_fsize = (GtkLabel*) g_object_new (GTK_TYPE_LABEL, "label",
 					      _("View the size of all Exchange folders"), NULL);
 	gtk_misc_set_alignment (GTK_MISC (lbl_fsize), 0, 0.5);
-	btn_fsize = (GtkButton*) g_object_new (GTK_TYPE_BUTTON, "label", _("Folders Size"), NULL);
+	btn_fsize = (GtkButton*) g_object_new (GTK_TYPE_BUTTON, "label", _("Folder Size"), NULL);
 	g_signal_connect (btn_fsize, "clicked", G_CALLBACK (folder_size_clicked), target_account->account);
 	gtk_table_attach_defaults (tbl_misc, GTK_WIDGET (lbl_fsize), 0, 1, 0, 1);
 	gtk_table_attach (tbl_misc, GTK_WIDGET (btn_fsize), 1, 2, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
diff --git a/src/addressbook/e-book-backend-mapi-gal.c b/src/addressbook/e-book-backend-mapi-gal.c
index e209a11..c4df69b 100644
--- a/src/addressbook/e-book-backend-mapi-gal.c
+++ b/src/addressbook/e-book-backend-mapi-gal.c
@@ -218,9 +218,9 @@ build_cache (EBookBackendMAPIGAL *ebmapi)
 			   First %d : Number of contacts cached till now.
 			   Second %d : Total number of contacts which need to be cached.
 			   So (%d/%d) displays the progress.
-			   Example: Caching the GAL entries (1200/50000)...
+			   Example: Caching the GAL entries (1200/50000)â?¦
 			*/
-			status_msg = g_strdup_printf (_("Caching the GAL entries (%d/%d)... "),
+			status_msg = g_strdup_printf (_("Caching the GAL entries (%d/%d)â?¦ "),
 							 i, contacts_array->len);
 			book_view_notify_status (book_view, status_msg);
 			g_free (status_msg);
@@ -779,7 +779,7 @@ book_view_thread (gpointer data)
 	g_object_ref (book_view);
 	e_flag_set (closure->running);
 
-	book_view_notify_status (book_view, "Searching...");
+	book_view_notify_status (book_view, "Searchingâ?¦");
 	query = e_data_book_view_get_card_query (book_view);
 
 	if (!find_book_view (backend))
@@ -797,7 +797,7 @@ book_view_thread (gpointer data)
 
 			if (priv->marked_for_offline && !priv->is_cache_ready) {
 				/* To translators : Here Evolution MAPI downloads the entries from the GAL server */
-				book_view_notify_status (book_view, _("Downloading GAL entries from server..."));
+				book_view_notify_status (book_view, _("Downloading GAL entries from serverâ?¦"));
 				return;
 			}
 
diff --git a/src/camel/camel-mapi-provider.c b/src/camel/camel-mapi-provider.c
index 6d7ea9f..3388b90 100644
--- a/src/camel/camel-mapi-provider.c
+++ b/src/camel/camel-mapi-provider.c
@@ -67,7 +67,7 @@ static CamelProvider mapi_provider = {
 
 	"Exchange MAPI",
 
-	N_("For accessing Microsoft Exchange / OpenChange servers using MAPI"),
+	N_("For accessing Microsoft Exchange/OpenChange servers using MAPI"),
 
 	"mail",
 
@@ -83,7 +83,7 @@ static CamelProvider mapi_provider = {
 
 CamelServiceAuthType camel_mapi_password_authtype = {
 	N_("Password"),
-	N_("This option will connect to the Openchange server using a plaintext password."),
+	N_("This option will connect to the OpenChange server using a plaintext password."),
 	"",
 	TRUE
 };
diff --git a/src/camel/camel-mapi-store.c b/src/camel/camel-mapi-store.c
index 46f3ac5..a2820de 100644
--- a/src/camel/camel-mapi-store.c
+++ b/src/camel/camel-mapi-store.c
@@ -578,7 +578,7 @@ mapi_create_folder(CamelStore *store, const gchar *parent_name, const gchar *fol
 	}
 
 	if (mapi_fid_is_system_folder (mapi_store, camel_mapi_store_folder_id_lookup (mapi_store, folder_name))) {
-		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, _("Cannot create new folder `%s'"),
+		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, _("Cannot create new folder '%s'"),
 				      folder_name);
 		return NULL;
 	}
@@ -762,7 +762,7 @@ mapi_rename_folder(CamelStore *store, const gchar *old_name, const gchar *new_na
 	if (!old_fid_str) {
 		/*To translators : '%s' is current name of the folder */
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
-				      _("Cannot rename MAPI folder `%s'. Folder does not exist."),
+				      _("Cannot rename MAPI folder '%s'. Folder does not exist."),
 				      old_name);
 		CAMEL_SERVICE_REC_UNLOCK (mapi_store, connect_lock);
 		return;
@@ -773,7 +773,7 @@ mapi_rename_folder(CamelStore *store, const gchar *old_name, const gchar *new_na
 		/*To translators : '%s to %s' is current name of the folder  and
 		 new name of the folder.*/
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
-				      _("Cannot rename MAPI default folder `%s' to `%s'."),
+				      _("Cannot rename MAPI default folder '%s' to '%s'."),
 				      old_name, new_name);
 		return;
 	}
@@ -797,7 +797,7 @@ mapi_rename_folder(CamelStore *store, const gchar *old_name, const gchar *new_na
 	}
 
 	if (!exchange_mapi_util_mapi_id_from_string (old_fid_str, &old_fid)) {
-		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, _("Cannot rename MAPI folder `%s' to `%s'"), old_name, new_name);
+		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, _("Cannot rename MAPI folder '%s' to '%s'"), old_name, new_name);
 		CAMEL_SERVICE_REC_UNLOCK (mapi_store, connect_lock);
 		g_free (old_parent);
 		g_free (new_parent);
@@ -812,7 +812,7 @@ mapi_rename_folder(CamelStore *store, const gchar *old_name, const gchar *new_na
 			/*To translators : '%s to %s' is current name of the folder  and
 			new name of the folder.*/
 			camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
-						  _("Cannot rename MAPI folder `%s' to `%s'"), old_name, new_name);
+						  _("Cannot rename MAPI folder '%s' to '%s'"), old_name, new_name);
 
 			CAMEL_SERVICE_REC_UNLOCK (mapi_store, connect_lock);
 			g_free (old_parent);
@@ -863,7 +863,7 @@ mapi_rename_folder(CamelStore *store, const gchar *old_name, const gchar *new_na
 			   !exchange_mapi_util_mapi_id_from_string (new_parent_fid_str, &new_parent_fid) ||
 			   !exchange_mapi_connection_move_folder (priv->conn, old_fid, old_parent_fid, new_parent_fid, tmp)) {
 			CAMEL_SERVICE_REC_UNLOCK (mapi_store, connect_lock);
-			camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, _("Cannot rename MAPI folder `%s' to `%s'"), old_name, new_name);
+			camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, _("Cannot rename MAPI folder '%s' to '%s'"), old_name, new_name);
 			g_free (old_parent);
 			g_free (new_parent);
 			return;



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/account-setup-eplugin/exchange-mapi-account-setup.c b/src/account-setup-eplugin/exchange-mapi-account-setup.c
index c6a285e..ded848e 100644
--- a/src/account-setup-eplugin/exchange-mapi-account-setup.c
+++ b/src/account-setup-eplugin/exchange-mapi-account-setup.c
@@ -145,7 +145,7 @@ create_profile_callback (struct SRowSet *rowset, gpointer data)
 
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (view),
-						     -1, _("User name"), renderer,
+						     -1, _("Username"), renderer,
 						     "text", COL_MAPI_ACCOUNT, NULL);
 
 	/* Model for TreeView */
@@ -202,7 +202,7 @@ validate_credentials (GtkWidget *widget, EConfig *config)
 	url = camel_url_new (e_account_get_string (target_account->account, E_ACCOUNT_SOURCE_URL), NULL);
 	domain_name = camel_url_get_param (url, "domain");
 
 	/* Silently remove domain part from a user name when user enters it as such.
 	   This change will be visible in the UI on new edit open. */
 	if (url->user && strchr (url->user, '\\')) {
 		gchar *tmp, *at;
@@ -202,7 +202,7 @@ validate_credentials (GtkWidget *widget, EConfig *config)
 	domain_name = camel_url_get_param (url, "domain");
 
-	/* Silently remove domain part from a user name when user enters it as such.
+	/* Silently remove domain part from a username when user enters it as such.
 	   This change will be visible in the UI on new edit open. */
 	if (url->user && strchr (url->user, '\\')) {